@@ -163,7 +163,7 @@ void SPVM_API_dec_ref_count(SPVM_ENV* env, SPVM_OBJECT* object);
 int32_t SPVM_API_ref_count(SPVM_ENV* env, SPVM_OBJECT* object);
 
 // Weak refernece
-void SPVM_API_weaken(SPVM_ENV* env, SPVM_OBJECT** object_address);
+int32_t SPVM_API_weaken(SPVM_ENV* env, SPVM_OBJECT** object_address);
 void SPVM_API_unweaken(SPVM_ENV* env, SPVM_OBJECT** object_address);
 int32_t SPVM_API_isweak(SPVM_ENV* env, SPVM_OBJECT** object_address);
 
